@@ -9,15 +9,17 @@ from kim_tools import get_isolated_energy_per_atom
 def test_get_isolated_energy_per_atom():
     for model in [
         LennardJones(),
-        "LennardJones612_UniversalShifted__MO_959249795837_003",
-        "Sim_LAMMPS_LJcut_AkersonElliott_Alchemy_PbAu",
+        "LJ_ElliottAkerson_2015_Universal__MO_959249795837_003",
+        "Sim_LAMMPS_ADP_StarikovGordeevLysogorskiy_2020_SiAuAl__SM_113843830602_000",
     ]:
-        for species in ["Pb", "Au"]:
+        for species in ["Au", "Al"]:
             assert np.isclose(
                 get_isolated_energy_per_atom(model=model, symbol=species),
                 0,
             )
-    # assert np.isclose(
-    #     get_isolated_energy_per_atom(LennardJonesFailNoNeighbors(), "H"),
-    #    0,
-    # )
+    """
+    assert np.isclose(
+         get_isolated_energy_per_atom(LennardJonesFailNoNeighbors(), "H"),
+        0,
+     )
+     """
